@@ -5,15 +5,6 @@ This is a "hello world" example demonstrating basic Breadcrumb usage.
 Learn how to trace simple function calls and query the results.
 """
 
-import sys
-sys.path.insert(0, '../../src')
-
-import breadcrumb
-
-# Initialize Breadcrumb tracing
-breadcrumb.init()
-
-
 def add(a, b):
     """Add two numbers."""
     return a + b
@@ -64,16 +55,5 @@ def main():
     print(f"   calculate_total(100, 2, 0.15) = ${total:.2f}")
     print()
 
-    print("=" * 60)
-    print("Execution complete! Traces captured.")
-    print("=" * 60)
-    print()
-    print("Next Steps:")
-    print("  1. Run: breadcrumb list")
-    print("  2. Run: breadcrumb query \"SELECT * FROM events WHERE function_name='add'\"")
-    print("  3. See README.md for more query examples")
-    print()
-
-
 if __name__ == "__main__":
     main()
