@@ -124,7 +124,7 @@ def _generate_timeout_report(timeout_seconds: int, db_path: Optional[str] = None
     print("=" * 60 + "\n", file=sys.stderr)
 
 
-def _generate_run_report(db_path: Optional[str] = None) -> None:
+def _generate_run_report(db_path: Optional[str] = None, config: Optional[str] = None) -> None:
     """
     Generate execution report after successful run.
 
@@ -260,68 +260,66 @@ def _generate_run_report(db_path: Optional[str] = None) -> None:
                 print(f"  (Too many events: {total_events} > 100)")
                 print(f"  Use 'breadcrumb query' to explore trace details")
 
-                # Show top 10 most called functions
-                top_functions = conn.execute("""
-                    SELECT module_name, function_name, COUNT(*) as call_count
-                    FROM trace_events
-                    WHERE trace_id = ? AND event_type = 'call'
-                    GROUP BY module_name, function_name
-                    ORDER BY call_count DESC
-                    LIMIT 10
-                """, (trace_id,)).fetchall()
+                
 
-                if top_functions:
-                    print(f"\n  Top 10 Most Called Functions:")
-                    for module, func, count in top_functions:
-                        print(f"    {module}.{func}: {count} calls")
+                print(f"\n  TIP: Use 'breadcrumb top 20' to see more!")
+                print(f"       Use 'breadcrumb top 20 --skip 10' to see positions 11-30")
+                print(f"       High call counts? Start with minimal tracing (['__main__'])")
+                print(f"       and expand based on --gaps analysis.")
 
-                    print(f"\n  TIP: Use 'breadcrumb top 20' to see more!")
-                    print(f"       Use 'breadcrumb top 20 --skip 10' to see positions 11-30")
-                    print(f"       High call counts? Consider excluding with:")
-                    print(f"       breadcrumb config edit <name> --add-exclude '<pattern>*'")
+            # Show top 10 most called functions
+            top_functions = conn.execute("""
+                SELECT module_name, function_name, COUNT(*) as call_count
+                FROM trace_events
+                WHERE trace_id = ? AND event_type = 'call'
+                GROUP BY module_name, function_name
+                ORDER BY call_count DESC
+                LIMIT 10
+            """, (trace_id,)).fetchall()
+
+            top = None
+            if top_functions:
+                print(f"\nTop 10 Most Called Functions:")
+                for module, func, count in top_functions:
+                    if top is None:
+                        top = f"{func}"
+                    print(f"    {module}.{func}: {count} calls")
+
+            # get just the filename (not path, and no extension) if possible
+            if config:
+                config = os.path.splitext(os.path.basename(os.path.abspath(config)))[0]
+            else:
+                config = os.path.splitext(os.path.basename(os.path.expanduser("~/.breadcrumb/config.yaml")))[0]
+                if not os.path.exists(config):
+                    config = None
+            print()
+            print("Recommendations on what to do next:")
+            print(f"  Detailed Flow: breadcrumb query -c {config} --flow")
+            print(f"  Untraced calls: breadcrumb query -c {config} --gaps")
+            
+            
+            print(f"  View specific call: breadcrumb query -c {config} --call <call_id>")
+            if top:
+                print(f"     Example '{top}': breadcrumb query -c {config} --call {top}")
+            print()
 
             print("\n" + "=" * 60 + "\n")
 
+
+            
+
     except Exception as e:
         # Silently fail - don't interrupt user's workflow
         pass
 
 
 def run_command(
-    command: List[str] = typer.Argument(..., help="Command to run with tracing enabled"),
-    timeout: int = typer.Option(
-        ...,
-        "--timeout",
-        "-t",
-        help="Maximum execution time in seconds (required for safety)"
-    ),
-    include: Optional[List[str]] = typer.Option(
-        None,
-        "--include",
-        "-i",
-        help="Module patterns to include (e.g., 'myapp.*'). Can be specified multiple times."
-    ),
-    exclude: Optional[List[str]] = typer.Option(
-        None,
-        "--exclude",
-        "-e",
-        help="Module patterns to exclude (e.g., 'flock.*'). Can be specified multiple times."
-    ),
-    db_path: Optional[str] = typer.Option(
-        None,
-        "--db-path",
-        help="Path to traces database (default: ~/.breadcrumb/traces.duckdb)"
-    ),
-    sample_rate: Optional[float] = typer.Option(
-        None,
-        "--sample-rate",
-        help="Sampling rate 0.0-1.0 (default: 1.0)"
-    ),
-    silent: bool = typer.Option(
-        False,
-        "--silent",
-        help="Suppress breadcrumb initialization message"
-    ),
+    command: List[str],
+    timeout: int,
+    include: Optional[List[str]] = None,
+    db_path: Optional[str] = None,
+    sample_rate: Optional[float] = None,
+    silent: bool = False,
     config_file: Optional[str] = None,
 ) -> None:
     """
@@ -338,12 +336,12 @@ def run_command(
         # Run with uv (2 minute timeout)
         breadcrumb run -t 120 uv run my_app.py
 
-        # Exclude frameworks (30 second timeout)
-        breadcrumb run -t 30 --exclude "flock.*" --exclude "pydantic.*" python main.py
-
         # Only trace your code (10 second timeout)
         breadcrumb run --timeout 10 --include "__main__" python script.py
 
+        # Trace multiple modules (30 second timeout)
+        breadcrumb run -t 30 --include "myapp.*" --include "flock.*" python main.py
+
         # Custom database path
         breadcrumb run -t 60 --db-path /tmp/traces.duckdb python main.py
 
@@ -361,9 +359,6 @@ def run_command(
         include_str = "[" + ", ".join(f"'{p}'" for p in include) + "]"
         init_args.append(f"include={include_str}")
 
-    if exclude:
-        exclude_str = "[" + ", ".join(f"'{p}'" for p in exclude) + "]"
-        init_args.append(f"exclude={exclude_str}")
 
     if db_path:
         init_args.append(f"db_path={repr(db_path)}")
@@ -452,7 +447,7 @@ finally:
                     result = subprocess.run(wrapper_command, timeout=timeout)
                     # Give writer thread time to flush (race condition workaround)
                     time.sleep(0.5)
-                    _generate_run_report(db_path)  # Show run report on success
+                    _generate_run_report(db_path, config_file)  # Show run report on success
                     sys.exit(result.returncode)
                 except subprocess.TimeoutExpired:
                     typer.echo(f"\nError: Command timed out after {timeout} seconds", err=True)
