@@ -429,14 +429,6 @@ def config_create_cmd(
             help="Module patterns to include (e.g., 'flock.*'). Can be specified multiple times.",
         ),
     ] = None,
-    exclude: Annotated[
-        Optional[List[str]],
-        typer.Option(
-            "--exclude",
-            "-e",
-            help="Module patterns to exclude (e.g., '*webhook*'). Can be specified multiple times.",
-        ),
-    ] = None,
     sample_rate: Annotated[
         Optional[float],
         typer.Option("--sample-rate", help="Sampling rate 0.0-1.0"),
@@ -445,33 +437,27 @@ def config_create_cmd(
         Optional[str],
         typer.Option("--db-path", help="Database path"),
     ] = None,
-    workspace_only: Annotated[
-        Optional[bool],
-        typer.Option("--workspace-only/--all-code", help="Only trace workspace code"),
-    ] = None,
     force: Annotated[
         bool,
         typer.Option("--force", "-f", help="Overwrite existing config"),
     ] = False,
 ):
     """
-    Create a new configuration profile.
+    Create a new configuration profile (AI-FIRST: include-only workflow).
 
     \b
     Examples:
-        breadcrumb config create flock --include "flock.*" --exclude "*webhook*"
+        breadcrumb config create flock --include "flock.*"
         breadcrumb config create production --sample-rate 0.1
-        breadcrumb config create debug --workspace-only
+        breadcrumb config create debug
     """
     from breadcrumb.cli.commands.config import config_create
 
     config_create(
         name=name,
         include=include,
-        exclude=exclude,
         sample_rate=sample_rate,
         db_path=db_path,
-        workspace_only=workspace_only,
         force=force,
     )
 
@@ -520,26 +506,14 @@ def config_edit_cmd(
         Optional[List[str]],
         typer.Option("--include", help="Replace include patterns (replaces entire list)"),
     ] = None,
-    exclude: Annotated[
-        Optional[List[str]],
-        typer.Option("--exclude", help="Replace exclude patterns (replaces entire list)"),
-    ] = None,
     add_include: Annotated[
         Optional[List[str]],
         typer.Option("--add-include", help="Add pattern to include list"),
     ] = None,
-    add_exclude: Annotated[
-        Optional[List[str]],
-        typer.Option("--add-exclude", help="Add pattern to exclude list"),
-    ] = None,
     remove_include: Annotated[
         Optional[List[str]],
         typer.Option("--remove-include", help="Remove pattern from include list"),
     ] = None,
-    remove_exclude: Annotated[
-        Optional[List[str]],
-        typer.Option("--remove-exclude", help="Remove pattern from exclude list"),
-    ] = None,
     sample_rate: Annotated[
         Optional[float],
         typer.Option("--sample-rate", help="Set sampling rate"),
@@ -552,17 +526,12 @@ def config_edit_cmd(
         Optional[bool],
         typer.Option("--enabled/--disabled", help="Enable/disable tracing"),
     ] = None,
-    workspace_only: Annotated[
-        Optional[bool],
-        typer.Option("--workspace-only/--all-code", help="Set workspace-only filtering"),
-    ] = None,
 ):
     """
-    Edit a configuration profile.
+    Edit a configuration profile (AI-FIRST: include-only workflow).
 
     \b
     Examples:
-        breadcrumb config edit flock --add-exclude "*webhook*"
         breadcrumb config edit flock --add-include "flock.agents.*"
         breadcrumb config edit production --sample-rate 0.5
         breadcrumb config edit debug --enabled
@@ -572,15 +541,11 @@ def config_edit_cmd(
     config_edit(
         name=name,
         include=include,
-        exclude=exclude,
         add_include=add_include,
-        add_exclude=add_exclude,
         remove_include=remove_include,
-        remove_exclude=remove_exclude,
         sample_rate=sample_rate,
         db_path=db_path,
         enabled=enabled,
-        workspace_only=workspace_only,
     )
 
 
@@ -695,15 +660,15 @@ def top(
     Show most frequently called functions (critical debugging tool).
 
     This is an ESSENTIAL feature for iterative debugging and config optimization!
-    Use it to identify noisy functions that should be excluded from tracing.
+    Use it to identify which functions dominate your traces.
 
     After running your script, check the top called functions:
       $ breadcrumb top 10
 
     You might see flock.logging is called 500 times. Ask yourself:
-    "Is this important for debugging? Probably not! Let's exclude it!"
+    "Is this important for debugging? Probably not! Focus on application code instead."
 
-      $ breadcrumb config edit myconfig --add-exclude "flock.logging*"
+    Start with minimal tracing (['__main__']) and expand based on --gaps analysis.
 
     Re-run with optimized config to focus on relevant code.
 
@@ -890,14 +855,6 @@ def run(
             help="Module patterns to include (e.g., 'myapp.*'). Can be specified multiple times.",
         ),
     ] = None,
-    exclude: Annotated[
-        Optional[List[str]],
-        typer.Option(
-            "--exclude",
-            "-e",
-            help="Module patterns to exclude (e.g., 'flock.*'). Can be specified multiple times.",
-        ),
-    ] = None,
     db_path: Annotated[
         Optional[str],
         typer.Option(
@@ -946,8 +903,8 @@ def run(
 
     \b
     Override config settings:
-        breadcrumb run -c myproject -t 60 --exclude "noisy.*" python app.py
         breadcrumb run -c myproject -t 60 --include "myapp.*" python app.py
+        breadcrumb run -c myproject -t 60 --include "myapp.*" --include "flock.*" python app.py
     """
     from breadcrumb.cli.commands.run import run_command
     from breadcrumb.cli.commands.config import load_config
@@ -978,7 +935,6 @@ def run(
     # Merge config file with command-line options (CLI takes precedence)
     # Config file values are used as defaults
     final_include = include if include is not None else config_values.get('include')
-    final_exclude = exclude if exclude is not None else config_values.get('exclude')
     final_db_path = db_path if db_path is not None else config_values.get('db_path')
     final_sample_rate = sample_rate if sample_rate is not None else config_values.get('sample_rate')
 
@@ -987,7 +943,6 @@ def run(
         command=command,
         timeout=timeout,
         include=final_include,
-        exclude=final_exclude,
         db_path=final_db_path,
         sample_rate=final_sample_rate,
         silent=silent,
